JSig class

A Java method signature, built from JTypes.

const add = JSig.of([JType.int_, JType.int_], returns: JType.int_);
add.descriptor;  // (II)I

Constructors

JSig.ctor(List<JType> parameters)
A constructor taking parameters. <init> always returns void.
const
JSig.of(List<JType> parameters, {JType returns = JType.void_})
A method taking parameters and returning returns (void by default).
const
JSig.parse(String declaration)
Parses a Java method declaration; see JavaMethod.parse for the grammar.
factory

Properties

descriptor String
The JNI descriptor, e.g. (II)I.
no setter
hashCode int
The hash code for this object.
no setteroverride
parameters List<JType>
final
returns JType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override