isReference property
bool
get
isReference
true when this is a class or array type.
Implementation
bool get isReference => JniType.isReference(descriptor);
true when this is a class or array type.
bool get isReference => JniType.isReference(descriptor);