floatFromBits function

double floatFromBits(
  1. int bits
)

Reinterprets the low 32 bits of bits as a jfloat.

Needed because CallFloatMethodA is bound with a Float return type on some paths and read back out of raw storage on others.

Implementation

double floatFromBits(int bits) => (ByteData(
  8,
)..setInt64(0, bits, Endian.little)).getFloat32(0, Endian.little);